==> wheezy.captcha-0.1.59.tar.gz: wheezy.captcha-0.1.59/README.md <==
# wheezy.captcha

[![Build Status](https://travis-ci.org/akornatskyy/wheezy.captcha.svg?branch=master)](https://travis-ci.org/akornatskyy/wheezy.captcha)
[![Coverage Status](https://coveralls.io/repos/github/akornatskyy/wheezy.captcha/badge.svg?branch=master)](https://coveralls.io/github/akornatskyy/wheezy.captcha?branch=master)
[![Documentation Status](https://readthedocs.org/projects/wheezycaptcha/badge/?version=latest)](https://wheezycaptcha.readthedocs.io/en/latest/?badge=latest)
[![pypi version](https://badge.fury.io/py/wheezy.captcha.svg)](https://badge.fury.io/py/wheezy.captcha)

[wheezy.captcha](https://pypi.org/project/wheezy.captcha/) is a
[python](http://www.python.org) package written in pure Python code. It
is a lightweight captcha library that provides integration with (one of
below must be installed):

- [PIL](http://www.pythonware.com/products/pil/) - Python Imaging
  Library 1.1.7.
- [Pillow](https://pypi.python.org/pypi/Pillow) - Python Imaging
  Library (fork).

It is optimized for performance, well tested and documented.

Resources:

- [source code](https://github.com/akornatskyy/wheezy.captcha),
  [examples](https://github.com/akornatskyy/wheezy.captcha/tree/master/demos)
  and [issues](https://github.com/akornatskyy/wheezy.captcha/issues)
  tracker are available on
  [github](https://github.com/akornatskyy/wheezy.captcha)
- [documentation](https://wheezycaptcha.readthedocs.io/en/latest/)

## Install

[wheezy.captcha](https://pypi.org/project/wheezy.captcha/) requires
[python](http://www.python.org) version 2.4 to 2.7 or 3.2+. It is
independent of operating system. You can install it from
[pypi](https://pypi.org/project/wheezy.captcha/) site (you need specify
extra requirements per imaging library of your choice):

```sh
pip install wheezy.captcha
pip install wheezy.captcha[PIL]
pip install wheezy.captcha[Pillow]
```

If you run into any issue or have comments, go ahead and add on
[github](https://github.com/akornatskyy/wheezy.captcha).

==> wheezy.captcha-3.0.1.tar.gz: wheezy.captcha-3.0.1/README.md <==
# wheezy.captcha

[![Build Status](https://travis-ci.org/akornatskyy/wheezy.captcha.svg?branch=master)](https://travis-ci.org/akornatskyy/wheezy.captcha)
[![Coverage Status](https://coveralls.io/repos/github/akornatskyy/wheezy.captcha/badge.svg?branch=master)](https://coveralls.io/github/akornatskyy/wheezy.captcha?branch=master)
[![Documentation Status](https://readthedocs.org/projects/wheezycaptcha/badge/?version=latest)](https://wheezycaptcha.readthedocs.io/en/latest/?badge=latest)
[![pypi version](https://badge.fury.io/py/wheezy.captcha.svg)](https://badge.fury.io/py/wheezy.captcha)

[wheezy.captcha](https://pypi.org/project/wheezy.captcha/) is a
[python](http://www.python.org) package written in pure Python code. It
is a lightweight captcha library that provides integration with (one of
below must be installed):

- [PIL](http://www.pythonware.com/products/pil/) - Python Imaging
  Library 1.1.7.
- [Pillow](https://pypi.python.org/pypi/Pillow) - Python Imaging
  Library (fork).

It is optimized for performance, well tested and documented.

Resources:

- [source code](https://github.com/akornatskyy/wheezy.captcha),
  [examples](https://github.com/akornatskyy/wheezy.captcha/tree/master/demos)
  and [issues](https://github.com/akornatskyy/wheezy.captcha/issues)
  tracker are available on
  [github](https://github.com/akornatskyy/wheezy.captcha)
- [documentation](https://wheezycaptcha.readthedocs.io/en/latest/)

## Install

[wheezy.captcha](https://pypi.org/project/wheezy.captcha/) requires
[python](http://www.python.org) version 3.6+. It is independent of operating
system. You can install it from
[pypi](https://pypi.org/project/wheezy.captcha/) site (you need specify
extra requirements per imaging library of your choice):

```sh
pip install wheezy.captcha
pip install wheezy.captcha[PIL]
pip install wheezy.captcha[Pillow]
```

If you run into any issue or have comments, go ahead and add on
[github](https://github.com/akornatskyy/wheezy.captcha).
